@@ -1,14 +1,15 @@
 # -*- coding: utf-8 -*-
+from __future__ import unicode_literals
 
+from builtins import chr, map, range, str
 import hashlib
 import re
-import string
+import unicodedata
 
 from datetime import datetime
-from django.core.exceptions import ValidationError
 from django.utils import formats, dateformat
-from django.utils.encoding import force_unicode
-from django.utils.functional import allow_lazy
+from django.utils.encoding import force_str
+from django.utils.functional import keep_lazy_text
 from django.utils.http import urlunquote
 
 
@@ -25,6 +26,7 @@ def format_datetime(value=None, date=True, time=True):
 def format_number(value=None, separator=','):
     if not value:
         return ''
+
     def split_thousands(s):
         if len(s) <= 3:
             return s
@@ -33,32 +35,34 @@ def format_number(value=None, separator=','):
 
 
 # From http://stackoverflow.com/questions/517923/what-is-the-best-way-to-remove-accents-in-a-python-unicode-string
-import unicodedata
-def strip_accents(str):
-    #return ''.join([c for c in unicodedata.normalize('NFD', str) if not unicodedata.combining(c)])
-    return unicodedata.normalize('NFD', unicode(str)).encode('ascii', 'ignore')
+def strip_accents(txt):
+    return unicodedata.normalize('NFD', str(txt)).encode('ascii', 'ignore').decode('ascii')
 
 
-def latin1_safe_xml_encode(str):
-    return unicode(str.encode('latin-1', 'xmlcharrefreplace'), 'latin-1')
+def latin1_safe_xml_encode(txt):
+    return str(txt.encode('latin-1', 'xmlcharrefreplace'), 'latin-1')
 
 
-xml_entity_table = string.maketrans(' \'', '--')
-def format_xml_entity(str):
-    return strip_accents(str).upper().translate(xml_entity_table)
+xml_entity_table = bytes.maketrans(b' \'', b'--')
 
 
+def format_xml_entity(txt):
+    return strip_accents(txt).encode('ascii').upper().translate(xml_entity_table)
+
+
+@keep_lazy_text
 def truncate_chars(s, num):
     "Truncates a string after a certain number of characters."
-    string = force_unicode(s)
+    txt = force_str(s)
     length = int(num)
-    if len(string) > length:
-        string = string[:length] + '...'
-    return string
-truncate_chars = allow_lazy(truncate_chars, unicode)
+    if len(txt) > length:
+        txt = txt[:length] + '...'
+    return txt
+
+
+rx_lettrine = re.compile(r"(\w)(\s)([\w-]+)([,.]{0,1}\s.*)", re.UNICODE | re.IGNORECASE)
 
 
-rx_lettrine = re.compile("(\w)(\s)([\w-]+)([,.]{0,1}\s.*)", re.UNICODE|re.IGNORECASE)
 def clean_lettrine(txt):
     """Vire les espaces ajoutés aux textes suite import QuarkXpress"""
     match = rx_lettrine.match(txt)
@@ -80,10 +84,10 @@ def clean_lettrine(txt):
 # see also: http://en.wikipedia.org/wiki/Roman_numerals
 # tested with Python24       vegaseat        25jan2007
 def int_to_roman(number):
-    numerals = { 1 : "I", 4 : "IV", 5 : "V", 9 : "IX", 10 : "X", 40 : "XL",
-        50 : "L", 90 : "XC", 100 : "C", 400 : "CD", 500 : "D", 900 : "CM", 1000 : "M" }
+    numerals = {1: "I", 4: "IV", 5: "V", 9: "IX", 10: "X", 40: "XL",
+                50: "L", 90: "XC", 100: "C", 400: "CD", 500: "D", 900: "CM", 1000: "M"}
     result = ""
-    for value, numeral in sorted(numerals.items(), reverse=True):
+    for value, numeral in sorted(list(numerals.items()), reverse=True):
         while number >= value:
             result += numeral
             number -= value
@@ -91,9 +95,11 @@ def int_to_roman(number):
 
 
 # Inspired by http://stackoverflow.com/questions/92438/stripping-non-printable-characters-from-a-string-in-python
-non_printable_re = re.compile('[%s]' % re.escape(''.join(map(unichr, range(0, 9) + range(11, 13) + range(14, 32) + range(127, 160)))))
-def filter_non_printable(str):
-    return non_printable_re.sub('', str)
+non_printable_re = re.compile('[%s]' % re.escape(''.join(map(chr, list(range(0, 9)) + list(range(11, 13)) + list(range(14, 32)) + list(range(127, 160))))))
+
+
+def filter_non_printable(txt):
+    return non_printable_re.sub('', txt)
 
 
 def simple_decorator(decorator):
@@ -123,7 +129,7 @@ def files_are_equal(f1, f2):
 
 def _digest_file(f, chunk_size=8192):
     md5 = hashlib.md5()
-    for chunk in iter(lambda: f.read(chunk_size), ""):
+    for chunk in iter(lambda: f.read(chunk_size), b""):
         md5.update(chunk)
     f.seek(0)
     return md5.digest()
@@ -137,17 +143,3 @@ def urldecode(url):
             k, v = param.split('=')
             out[k] = urlunquote(v)
     return out
-
-
-NO_CAPFIRST = ['de', 'des', 'du', 'le', 'la', 'les', 'd', 'l', 'a', 'au', 'aux']
-def lowerize(txt, excluded=[]):
-    words = txt.split(' ')
-    cap_words = []
-    for i, word in enumerate(words):
-        if not word:
-            continue
-        word = word.lower()
-        if not (word in excluded and i>0):
-            word = word[0].capitalize() + word[1:]
-        cap_words.append(word)
-    return " ".join(cap_words)
